#!/bin/bash


# Slackware build script for rdesktop
# Author: Mark Tucker
# Created: Jul 30, 2004
# Changes:
#        Jul 30, 2004 - initial creation
#

#
#----------------------------------------------------------------------
umask 0022
#----------------------------------------
# Package variables
#----------------------------------------
source="rdesktop-1.3.1.tar.gz"
pkgname="rdesktop"
pkgver="1.3.1"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
# where our source archive is located
srcdir=`pwd`/SRC
thisfile=`pwd`/`basename $0`
# get working directory
workdir=`dirname $0`
if [ "$workdir" == "." ]; then
    workdir=`pwd`/$pkgname
    if [ ! -d $workdir ]; then
	echo Creating working directory $workdir ...
	mkdir -p $workdir
    fi
    echo Working directory is $workdir
    cd $workdir
    echo Changed directory to  `pwd`
fi



# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source


builddir=$workdir/$pkgname-$pkgver
cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS

#----------------------------------------
# configure 
#----------------------------------------
echo Running configure...
./configure --prefix=/usr \
    > $workdir/config.output 2>&1

if [ $? -ne 0 ]; then
    echo There was a problem with the build process.
    echo check the contents of $workdir/config.output
    echo Exiting...
    exit
fi

#----------------------------------------
# make
#----------------------------------------
echo Running make...
make > $workdir/make.output 2>&1
if [ $? -ne 0 ]; then
    echo There was a problem with the build process.
    echo check the contents of $workdir/make.output
    echo Exiting...
    exit
fi

#----------------------------------------
# Set target directory
#----------------------------------------
target=$workdir/target
if [ ! -d $target ]; then
    mkdir $target
fi

#----------------------------------------
# install
#----------------------------------------
echo Installing to $target ...
make install DESTDIR=$target > $workdir/install.output 2>&1


echo finishing install...


# create install dir
mkdir $target/install

# create slack-desc file to install
 cat > $target/install/slack-desc << END
        |-----handy-ruler------------------------------------------------------|
rdesktop: rdesktop  1.3.1 
rdesktop:
rdesktop: rdesktop is an open source client for Windows NT Terminal Server and
rdesktop: Windows 2000/2003 Terminal Services, capable of natively speaking
rdesktop: Remote Desktop Protocol (RDP) in order to present the user's NT 
rdesktop: desktop. 
rdesktop:
rdesktop: 
rdesktop: http://www.rdesktop.org/
rdesktop: 
rdesktop: Packaged by Mark Tucker for Slackware 10.0
END

# create documentation directory
mkdir -p $target/usr/doc/$pkgname-$pkgver
cp $workdir/$pkgname-$pkgver/[A-Z]* $target/usr/doc/$pkgname-$pkgver/
chmod a+r $target/usr/doc/$pkgname-$pkgver/*
cp $thisfile $target/usr/doc/$pkgname-$pkgver/SlackPkg.sh

#----------------------------------------
# fix group on bin directories.
#----------------------------------------
for i in bin sbin usr/sbin usr/bin usr/X11R6/bin
do
  if [ -d $target/$i ]; then
      echo Changing group on $target/$i
      chgrp -R bin $target/$i
  fi
done

#----------------------------------------
# check for uncompressed man pages
#----------------------------------------
for i in usr/man opt/man usr/share/man
do
  if [ -d $target/$i ]; then
      find $target/$i -name \*.[0-9] -exec gzip {} \;
  fi
done


#----------------------------------------
# package specific stuff goes here
#----------------------------------------

#----------------------------------------
# makepkg
#----------------------------------------
cd $target
echo Creating package...
makepkg  -c n -l y $workdir/$package 

cd $workdir
echo DONE
exit

